##  Functional Review
This section outlines criteria of the functional review.
### Stability
The report must run out of the box without generating any unhandled errors.
### Look and Feel
Reports should be using the same look and feel as default reports, including the following:
  * Filtering
  * Configuration
  * Design


### Use cases
Reports need to have a clear use case.
YesNo
Send
